@@ -4,7 +4,7 @@ use ExtUtils::MakeMaker;
 WriteMakefile(
 	      NAME => 'Xcode::Project',
 	      VERSION_FROM => 'lib/Xcode/Project.pm',
-	      ABSTRACT_FROM => 'lib/Xcode/Project.pm',
+#	      ABSTRACT_FROM => 'lib/Xcode/Project.pm',
 	      AUTHOR => 'John Tsai',
 	      LICENSE => 'freebsd',
 	      MIN_PERL_VERSION => '5.016000',
